@@ -9,7 +9,7 @@ vserver!1!rule!460!handler!url = http://www.cherokee-project.com
 
 class Test (TestBase):
     def __init__ (self):
-        TestBase.__init__ (self)
+        TestBase.__init__ (self, __file__)
         self.name = "Redir to URL"
 
         self.request          = "GET /redir46/ HTTP/1.0\r\n"
